WORKAREA.analytics.registerAdapter('facebookConversionTracking', function () {
    'use strict';

    return {
        addToCart: function (payload) {
            var eventName = 'AddToCart',
                contentType = 'product_group',
                eventId = payload.event_id,
                products = [
                    {
                        id: payload.id,
                        name: payload.name,
                        sku: payload.sku,
                        sale: payload.sale,
                        price: payload.price,
                        category: payload.category
                    }
                ],
                serverPayload = {
                    event: eventName,
                    event_id: eventId,
                    event_source_url: window.location.href,
                    content_type: contentType,
                    products: products
                },
                browserPayload = {
                    name: [payload.name],
                    sku: [payload.sku],
                    sale: [payload.sale],
                    price: [payload.price],
                    category: [payload.category],
                    content_type: contentType,
                    content_ids: [payload.sku]
                };

            $.ajax({
                type: 'POST',
                url: WORKAREA.routes.storefront.facebookConversionTrackingAddToCartPath(),
                data: serverPayload
            });

            if (_.isUndefined(window.fbq)) {
                setTimeout(function() {
                  fbq('track', eventName, browserPayload, { eventID: eventId });
                }, 3000);
            } else {
                fbq('track', eventName, browserPayload, { eventID: eventId });
            };
        },

        checkoutOrderPlaced: function (payload) {
            var eventName = 'Purchase',
                contentType = 'product_group',
                eventId = payload.event_id,
                products = [];

            _.each(payload.items, function (impression) {
                products.push({
                    id: impression.product_id,
                    name: impression.product_name,
                    sku: impression.sku,
                    price: impression.price,
                    quantity: impression.quantity,
                    category: impression.category
                });
            });

            var serverPayload = {
                event: eventName,
                event_id: eventId,
                event_source_url: window.location.href,
                id: payload.id,
                promo_codes: payload.promo_codes,
                shipping_service: payload.shipping_service,
                shipping_total: payload.shipping_total,
                tax_total: payload.tax_total,
                tenders: payload.tenders,
                value: payload.total_price,
                currency: payload.currency,
                content_type: contentType,
                products: products
            },
            browserPayload = {
                id: payload.id,
                promo_codes: payload.promo_codes,
                shipping_service: payload.shipping_service,
                shipping_total: payload.shipping_total,
                tax_total: payload.tax_total,
                tenders: payload.tenders,
                value: payload.total_price,
                currency: payload.currency,
                content_type: contentType,
                content_ids: _.map(products, 'id'),
                name: _.map(products, 'name'),
                sku: _.map(products, 'sku'),
                price: _.map(products, 'price'),
                quantity: _.map(products, 'quantity'),
                category: _.map(products, 'category')
            };

            $.ajax({
                type: 'POST',
                url: WORKAREA.routes.storefront.facebookConversionTrackingPurchasePath(),
                data: serverPayload
            });

            if (_.isUndefined(window.fbq)) {
                setTimeout(function() {
                  fbq('track', eventName, browserPayload, { eventID: eventId });
                }, 3000);
            } else {
                fbq('track', eventName, browserPayload, { eventID: eventId });
            };
        },
    };
});
