require 'net/http'
require 'uri'
require 'json'

module Workarea
  class FacebookConversionTrackingGateway
    def initialize(payload)
      @payload = payload
    end

    def send
      begin
        response = conn.post do |req|
          req.params['data'] = @payload.to_json
        end

        handle_response(response)
      rescue => e
        Raven.capture_message("Facebook Conversion Tracking POST Error: #{e}", level: 'error')
      end
    end

    private

    def handle_response(response)
      parsed_resp = JSON.parse(response.body)

      if response.status != 200
        Raven.capture_message("Facebook Conversion Tracking Error: #{parsed_resp}", level: 'error')
      else
        parsed_resp
      end
    end

    def conn
      @conn ||=
        Faraday.new(
          url: URI.parse(url),
          params: conn_params,
          headers: { 'Content-Type' => 'application/json' }
        )
    end

    # We only want to use the test code when testing on dev.
    def conn_params
      return unless Workarea::FacebookConversionTracking.configured?

      test_code = Rails.env.development? ? { test_event_code: test_code } : {}
      { access_token: access_token }.merge(test_code)
    end

    def url
      "https://graph.facebook.com/v11.0/#{pixel_id}/events"
    end

    def pixel_id
      Workarea::FacebookConversionTracking.pixel_id
    end

    def access_token
      Workarea::FacebookConversionTracking.access_token
    end

    def test_code
      Workarea::FacebookConversionTracking.test_code
    end
  end
end
